pub struct PartiallyUnwrappedPacket { /* private fields */ }Implementations
Sourceimpl PartiallyUnwrappedPacket
impl PartiallyUnwrappedPacket
Sourcepub fn new(
received_data: FramedNymPacket,
sphinx_key: &PrivateKey,
) -> Result<Self, (FramedNymPacket, PacketProcessingError)>
pub fn new( received_data: FramedNymPacket, sphinx_key: &PrivateKey, ) -> Result<Self, (FramedNymPacket, PacketProcessingError)>
Attempt to partially unwrap received packet to derive relevant keys to allow us to reject it for obvious bad behaviour (like replay or invalid mac) without performing full processing
pub fn finalise_unwrapping( self, ) -> Result<MixProcessingResult, PacketProcessingError>
pub fn replay_tag(&self) -> Option<&[u8; 32]>
pub fn with_key_rotation( self, used_key_rotation: u32, ) -> PartialyUnwrappedPacketWithKeyRotation